.. _storage-api:

Data IO
=======

Raw data
--------

.. autoclass:: tidyms2.MSData
   :members:

Matrix data readers
-------------------

.. automodule:: tidyms2.io.matrix
   :members:

Storage classes
---------------

.. automodule:: tidyms2.storage
   :members:
